pub struct DCON_C_R(/* private fields */);Expand description
Field DCON_C reader - Device status - connect change. The Connect Change bit is set when the device’s pull-up resistor is disconnected because VBus disappeared. The bit is reset by writing a one to it.