pub struct DEV_ADDR_W<'a> { /* private fields */ }Expand description
Field DEV_ADDR writer - USB device address. After bus reset, the address is reset to 0x00. If the enable bit is set, the device will respond on packets for function address DEV_ADDR. When receiving a SetAddress Control Request from the USB host, software must program the new address before completing the status phase of the SetAddress Control Request.
Implementations