pub struct DRES_C_W<'a> { /* private fields */ }Expand description
Field DRES_C writer - Device status - reset change. This bit is set when the device received a bus reset. On a bus reset the device will automatically go to the default state (unconfigured and responding to address 0). The bit is reset by writing a one to it.
Implementations