pub struct DSUS_C_W<'a> { /* private fields */ }Expand description
Field DSUS_C writer - Device status - suspend change. The suspend change bit is set to 1 when the suspend bit toggles. The suspend bit can toggle because: - The device goes in the suspended state - The device is disconnected - The device receives resume signaling on its upstream port. The bit is reset by writing a one to it.
Implementations