pub struct INTONNAK_AI_R(/* private fields */);Expand description
Field INTONNAK_AI reader - Interrupt on NAK for interrupt and bulk IN EP
Implementations
Sourceimpl INTONNAK_AI_R
impl INTONNAK_AI_R
Sourcepub fn variant(&self) -> INTONNAK_AI_A
pub fn variant(&self) -> INTONNAK_AI_A
Get enumerated values variant
Sourcepub fn is_disabled(&self) -> bool
pub fn is_disabled(&self) -> bool
Checks if the value of the field is DISABLED
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Checks if the value of the field is ENABLED