W

Struct W 

pub struct W(/* private fields */);
Register INTSETSTAT writer

Implementations

Source

impl W

pub fn ep_set_int(&mut self) -> EP_SET_INT_W<'_>

Bits 0:9 - If software writes a one to one of these bits, the corresponding USB interrupt status bit is set. When this register is read, the same value as the USB interrupt status register is returned.

pub fn frame_set_int(&mut self) -> FRAME_SET_INT_W<'_>

Bit 30 - If software writes a one to one of these bits, the corresponding USB interrupt status bit is set. When this register is read, the same value as the USB interrupt status register is returned.

pub fn dev_set_int(&mut self) -> DEV_SET_INT_W<'_>

Bit 31 - If software writes a one to one of these bits, the corresponding USB interrupt status bit is set. When this register is read, the same value as the USB interrupt status register is returned.

pub unsafe fn bits(&mut self, bits: u32) -> &mut Self

Writes raw bits to the register.