USB Device Command/Status register
Structs
- DCON_
C_ R - Field
DCON_Creader - Device status - connect change. The Connect Change bit is set when the device’s pull-up resistor is disconnected because VBus disappeared. The bit is reset by writing a one to it. - DCON_
C_ W - Field
DCON_Cwriter - Device status - connect change. The Connect Change bit is set when the device’s pull-up resistor is disconnected because VBus disappeared. The bit is reset by writing a one to it. - DCON_R
- Field
DCONreader - Device status - connect. The connect bit must be set by SW to indicate that the device must signal a connect. The pull-up resistor on USB_DP will be enabled when this bit is set and the VBUSDEBOUNCED bit is one. - DCON_W
- Field
DCONwriter - Device status - connect. The connect bit must be set by SW to indicate that the device must signal a connect. The pull-up resistor on USB_DP will be enabled when this bit is set and the VBUSDEBOUNCED bit is one. - DEVCMDSTAT_
SPEC - USB Device Command/Status register
- DEV_
ADDR_ R - Field
DEV_ADDRreader - USB device address. After bus reset, the address is reset to 0x00. If the enable bit is set, the device will respond on packets for function address DEV_ADDR. When receiving a SetAddress Control Request from the USB host, software must program the new address before completing the status phase of the SetAddress Control Request. - DEV_
ADDR_ W - Field
DEV_ADDRwriter - USB device address. After bus reset, the address is reset to 0x00. If the enable bit is set, the device will respond on packets for function address DEV_ADDR. When receiving a SetAddress Control Request from the USB host, software must program the new address before completing the status phase of the SetAddress Control Request. - DEV_
EN_ R - Field
DEV_ENreader - USB device enable. If this bit is set, the HW will start responding on packets for function address DEV_ADDR. - DEV_
EN_ W - Field
DEV_ENwriter - USB device enable. If this bit is set, the HW will start responding on packets for function address DEV_ADDR. - DRES_
C_ R - Field
DRES_Creader - Device status - reset change. This bit is set when the device received a bus reset. On a bus reset the device will automatically go to the default state (unconfigured and responding to address 0). The bit is reset by writing a one to it. - DRES_
C_ W - Field
DRES_Cwriter - Device status - reset change. This bit is set when the device received a bus reset. On a bus reset the device will automatically go to the default state (unconfigured and responding to address 0). The bit is reset by writing a one to it. - DSUS_
C_ R - Field
DSUS_Creader - Device status - suspend change. The suspend change bit is set to 1 when the suspend bit toggles. The suspend bit can toggle because: - The device goes in the suspended state - The device is disconnected - The device receives resume signaling on its upstream port. The bit is reset by writing a one to it. - DSUS_
C_ W - Field
DSUS_Cwriter - Device status - suspend change. The suspend change bit is set to 1 when the suspend bit toggles. The suspend bit can toggle because: - The device goes in the suspended state - The device is disconnected - The device receives resume signaling on its upstream port. The bit is reset by writing a one to it. - DSUS_R
- Field
DSUSreader - Device status - suspend. The suspend bit indicates the current suspend state. It is set to 1 when the device hasn’t seen any activity on its upstream port for more than 3 milliseconds. It is reset to 0 on any activity. When the device is suspended (Suspend bit DSUS = 1) and the software writes a 0 to it, the device will generate a remote wake-up. This will only happen when the device is connected (Connect bit = 1). When the device is not connected or not suspended, a writing a 0 has no effect. Writing a 1 never has an effect. - DSUS_W
- Field
DSUSwriter - Device status - suspend. The suspend bit indicates the current suspend state. It is set to 1 when the device hasn’t seen any activity on its upstream port for more than 3 milliseconds. It is reset to 0 on any activity. When the device is suspended (Suspend bit DSUS = 1) and the software writes a 0 to it, the device will generate a remote wake-up. This will only happen when the device is connected (Connect bit = 1). When the device is not connected or not suspended, a writing a 0 has no effect. Writing a 1 never has an effect. - FORCE_
NEEDCLK_ R - Field
FORCE_NEEDCLKreader - Forces the NEEDCLK output to always be on: - FORCE_
NEEDCLK_ W - Field
FORCE_NEEDCLKwriter - Forces the NEEDCLK output to always be on: - INTONNAK_
AI_ R - Field
INTONNAK_AIreader - Interrupt on NAK for interrupt and bulk IN EP - INTONNAK_
AI_ W - Field
INTONNAK_AIwriter - Interrupt on NAK for interrupt and bulk IN EP - INTONNAK_
AO_ R - Field
INTONNAK_AOreader - Interrupt on NAK for interrupt and bulk OUT EP - INTONNAK_
AO_ W - Field
INTONNAK_AOwriter - Interrupt on NAK for interrupt and bulk OUT EP - INTONNAK_
CI_ R - Field
INTONNAK_CIreader - Interrupt on NAK for control IN EP - INTONNAK_
CI_ W - Field
INTONNAK_CIwriter - Interrupt on NAK for control IN EP - INTONNAK_
CO_ R - Field
INTONNAK_COreader - Interrupt on NAK for control OUT EP - INTONNAK_
CO_ W - Field
INTONNAK_COwriter - Interrupt on NAK for control OUT EP - LPM_
REWP_ R - Field
LPM_REWPreader - LPM Remote Wake-up Enabled by USB host. HW sets this bit to one when the bRemoteWake bit in the LPM extended token is set to 1. HW will reset this bit to 0 when it receives the host initiated LPM resume, when a remote wake-up is sent by the device or when a USB bus reset is received. Software can use this bit to check if the remote wake-up feature is enabled by the host for the LPM transaction. - LPM_
SUP_ R - Field
LPM_SUPreader - LPM Supported: - LPM_
SUP_ W - Field
LPM_SUPwriter - LPM Supported: - LPM_
SUS_ R - Field
LPM_SUSreader - Device status - LPM Suspend. This bit represents the current LPM suspend state. It is set to 1 by HW when the device has acknowledged the LPM request from the USB host and the Token Retry Time of 10 ms has elapsed. When the device is in the LPM suspended state (LPM suspend bit = 1) and the software writes a zero to this bit, the device will generate a remote walk-up. Software can only write a zero to this bit when the LPM_REWP bit is set to 1. HW resets this bit when it receives a host initiated resume. HW only updates the LPM_SUS bit when the LPM_SUPP bit is equal to one. - LPM_
SUS_ W - Field
LPM_SUSwriter - Device status - LPM Suspend. This bit represents the current LPM suspend state. It is set to 1 by HW when the device has acknowledged the LPM request from the USB host and the Token Retry Time of 10 ms has elapsed. When the device is in the LPM suspended state (LPM suspend bit = 1) and the software writes a zero to this bit, the device will generate a remote walk-up. Software can only write a zero to this bit when the LPM_REWP bit is set to 1. HW resets this bit when it receives a host initiated resume. HW only updates the LPM_SUS bit when the LPM_SUPP bit is equal to one. - R
- Register
DEVCMDSTATreader - SETUP_R
- Field
SETUPreader - SETUP token received. If a SETUP token is received and acknowledged by the device, this bit is set. As long as this bit is set all received IN and OUT tokens will be NAKed by HW. SW must clear this bit by writing a one. If this bit is zero, HW will handle the tokens to the CTRL EP0 as indicated by the CTRL EP0 IN and OUT data information programmed by SW. - SETUP_W
- Field
SETUPwriter - SETUP token received. If a SETUP token is received and acknowledged by the device, this bit is set. As long as this bit is set all received IN and OUT tokens will be NAKed by HW. SW must clear this bit by writing a one. If this bit is zero, HW will handle the tokens to the CTRL EP0 as indicated by the CTRL EP0 IN and OUT data information programmed by SW. - VBUSDEBOUNCED_
R - Field
VBUSDEBOUNCEDreader - This bit indicates if Vbus is detected or not. The bit raises immediately when Vbus becomes high. It drops to zero if Vbus is low for at least 3 ms. If this bit is high and the DCon bit is set, the HW will enable the pull-up resistor to signal a connect. - W
- Register
DEVCMDSTATwriter
Enums
- FORCE_
NEEDCLK_ A - Forces the NEEDCLK output to always be on:
- INTONNAK_
AI_ A - Interrupt on NAK for interrupt and bulk IN EP
- INTONNAK_
AO_ A - Interrupt on NAK for interrupt and bulk OUT EP
- INTONNAK_
CI_ A - Interrupt on NAK for control IN EP
- INTONNAK_
CO_ A - Interrupt on NAK for control OUT EP
- LPM_
SUP_ A - LPM Supported: