pub struct DEV_SET_INT_R(/* private fields */);Expand description
Field DEV_SET_INT reader - If software writes a one to one of these bits, the corresponding USB interrupt status bit is set. When this register is read, the same value as the USB interrupt status register is returned.